@@ -7,12 +7,13 @@
 # @Date   : 2021-07-26 10:54:14
 # --------------------------------------------------------
 """
-from ..engine import base
+from ..engine import base, comm
 
 
 class Callback(base.Base):
     def __init__(self):
         self.model = None
+        self.is_main_process = comm.is_main_process()
 
     def set_model(self, model):
         self.model = model
