@@ -25,28 +25,24 @@ def parser_work_space(cfg, flags: list = [], time=True):
     return work_dir
 
 
-def parser_config(args, cfg_updata=True):
+def parser_config(args: argparse.Namespace, cfg_updata: bool = True):
     """
-    :param args:
-    :param cfg_updata:
+    解析并合并配置参数：(1)命令行argparse (2)使用*.yaml配置文件
+    :param args: 命令行参数
+    :param cfg_updata:True: 合并配置参数时，相同参数由*.yaml文件参数决定
+                     False: 合并配置参数时，相同参数由命令行argparse参数决定
     :return:
     """
-    if cfg_updata:
-        try:
-            cfg = load_config(args.config_file)
+    if "config_file" in args and args.config_file:
+        cfg = load_config(args.config_file)
+        if cfg_updata:
             cfg = dict(args.__dict__, **cfg)
-            cfg["config_file"] = args.config_file
-        except:
-            cfg = args.__dict__
-            cfg['config_file'] = save_config(cfg, 'args_config.yaml')
-    else:
-        try:
-            cfg = load_config(args.config_file)
+        else:
             cfg = dict(cfg, **args.__dict__)
-            cfg["config_file"] = args.config_file
-        except:
-            cfg = args.__dict__
-            cfg['config_file'] = save_config(cfg, 'args_config.yaml')
+        cfg["config_file"] = args.config_file
+    else:
+        cfg = args.__dict__
+        cfg['config_file'] = save_config(cfg, 'args_config.yaml')
     print_dict(cfg)
     cfg = easydict.EasyDict(cfg)
     return cfg
