@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """
 # --------------------------------------------------------
-# @Project: torch-anti-spoofing-pipeline
 # @Author : panjq
 # @E-mail : pan_jinquan@163.com
 # @Date   : 2020-06-02 16:00:47
@@ -195,8 +194,7 @@ def load_state_dict(model_path, module=True):
         if module:
             state_dict = get_module_state_dict(state_dict)
     else:
-        print("Error:no model file:{}".format(model_path))
-        exit(0)
+        raise Exception("Error:no model file:{}".format(model_path))
     return state_dict
 
 
@@ -216,6 +214,53 @@ def get_module_state_dict(state_dict):
     return new_state_dict
 
 
+def load_pretrained_model(model, ckpt):
+    """Loads pretrianed weights to model.
+    Features:只会加载完全匹配的模型参数，不匹配的模型将会忽略
+        - Incompatible layers (unmatched in name or size) will be ignored.
+        - Can automatically deal with keys containing "module.".
+    Args:
+        model (nn.Module): network model.
+        ckpt (str): OrderedDict or model file
+    """
+    if isinstance(ckpt, str):
+        checkpoint = load_state_dict(ckpt)
+        if 'state_dict' in checkpoint:
+            state_dict = checkpoint['state_dict']
+        else:
+            state_dict = checkpoint
+    elif isinstance(ckpt, OrderedDict):
+        state_dict = ckpt
+    else:
+        raise Exception("nonsupport type:{} ".format(ckpt))
+    model_dict = model.state_dict()
+    new_state_dict = OrderedDict()
+    matched_layers, discarded_layers = [], []
+    for k, v in state_dict.items():
+        if k.startswith('module.'):
+            k = k[7:]  # discard module.
+        if k in model_dict and model_dict[k].size() == v.size():
+            new_state_dict[k] = v
+            matched_layers.append(k)
+        else:
+            discarded_layers.append(k)
+    model_dict.update(new_state_dict)
+    model.load_state_dict(model_dict)
+    print("=" * 60)
+    if len(matched_layers) == 0:
+        raise Exception('The model checkpoint cannot be loaded,'
+                        'please check the key names manually')
+    else:
+        print('Successfully loaded model checkpoint')
+        # [print('{}'.format(layer)) for layer in matched_layers]
+        if len(discarded_layers) > 0:
+            print('The following layers are discarded due to unmatched keys or layer size')
+            [print('{}'.format(layer)) for layer in discarded_layers]
+
+    print("=" * 60)
+    return model
+
+
 def plot_model(model, output=None, input_shape=None):
     """
     Usage:
@@ -286,13 +331,67 @@ def summary_model(model, batch_size=1, input_size=[112, 112], plot=False, device
     model = model.to(device)
     model.eval()
     output = model(inputs)
+    # 统计模型参数
     summary(model, input_size=(3, input_size[1], input_size[0]), batch_size=batch_size, device=device)
+    # 统计模型参数和计算FLOPs
     stat(model, (3, input_size[1], input_size[0]))
+    # summary可能报错，可使用该方法
+    # summary_v2(model, inputs, item_length=26, verbose=True)
+    # from thop import profile
+    # macs, params = profile(model, inputs=(inputs,))
+    # print("Total Flops :{}".format(macs))
+    # print("Total params:{}".format(params))
+    print("===" * 10)
+    print("inputs.shape:{}".format(inputs.shape))
+    # print("output.shape:{}".format(output.shape))
+    if plot:
+        plot_model(model, output)
+
+
+def torchinfo_summary(model, batch_size=1, input_size=[112, 112], plot=False, device="cpu"):
+    """
+    ----This tools can show----
+    Total params: 359,592
+    Total memory: 47.32MB
+    Total MAdd: 297.37MMAdd
+    Total Flops: 153.31MFlops
+    Total MemR+W: 99.7MB
+    ====================================================
+    https://www.cnblogs.com/xuanyuyt/p/12653041.html
+    Total number of network parameters (params)
+    Theoretical amount of floating point arithmetics (FLOPs)
+    Theoretical amount of multiply-adds (MAdd MACC) (乘加运算)
+    Memory usage (memory)
+    MACCs：是multiply-accumulate operations，指点积运算， 一个 macc = 2FLOPs
+    FLOPs 的全称是 floating points of operations，即浮点运算次数，用来衡量模型的计算复杂度。
+    计算 FLOPs 实际上是计算模型中乘法和加法的运算次数。
+    卷积层的浮点运算次数不仅取决于卷积核的大小和输入输出通道数，还取决于特征图的大小；
+    而全连接层的浮点运算次数和参数量是相同的。
+    ====================================================
+    :param model:
+    :param batch_size:
+    :param input_size:
+    :param plot: plot model
+    :param device:
+    :return:
+    """
+    from torchinfo import summary
+    from torchstat import stat
+    inputs = torch.randn(size=(batch_size, 3, input_size[1], input_size[0]))
+    inputs = inputs.to(device)
+    model = model.to(device)
+    model.eval()
+    output = model(inputs)
+    # 统计模型参数
+    summary(model, input_size=(batch_size, 3, input_size[1], input_size[0]), device=device)
+    # 统计模型参数和计算FLOPs
+    stat(model, (3, input_size[1], input_size[0]))
+    # summary可能报错，可使用该方法
+    # summary_v2(model, inputs, item_length=26, verbose=True)
     # from thop import profile
     # macs, params = profile(model, inputs=(inputs,))
     # print("Total Flops :{}".format(macs))
     # print("Total params:{}".format(params))
-
     print("===" * 10)
     print("inputs.shape:{}".format(inputs.shape))
     # print("output.shape:{}".format(output.shape))
